@@ -2,7 +2,7 @@ package t::TestUtils;
 
 use strict;
 use warnings;
-use HTTP::Tiny;
+use HTTP::Tiny 0.058;
 use Test::TCP;
 use Plack::Test qw//;
 use base qw/Exporter/;
@@ -23,9 +23,9 @@ our $HTTP_VER = "1.1";
 {
     no warnings 'redefine';
     sub HTTP::Tiny::Handle::write_request_header {
-        @_ == 4 || die(q/Usage: $handle->write_request_header(method, request_uri, headers)/ . "\n");
-        my ($self, $method, $request_uri, $headers) = @_;
-        return $self->write_header_lines($headers, "$method $request_uri HTTP/$HTTP_VER\x0D\x0A");
+        @_ == 5 || die(q/Usage: $handle->write_request_header(method, request_uri, headers, header_case)/ . "\n");
+        my ($self, $method, $request_uri, $headers, $header_case) = @_;
+        return $self->write_header_lines($headers, $header_case, "$method $request_uri HTTP/$HTTP_VER\x0D\x0A");
     }
 }
 
